You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by er...@apache.org on 2019/12/02 07:22:45 UTC

[commons-math] branch master updated (735dbc7 -> 1c3ccc4)

This is an automated email from the ASF dual-hosted git repository.

erans pushed a change to branch master
in repository https://gitbox.apache.org/repos/asf/commons-math.git.


    from 735dbc7  MATH-1469: Removal of codes ported to "Commons Geometry".
     new a9c64a5  Javadoc.
     new 1c3ccc4  Javadoc.

The 2 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 .../commons/math4/field/linalg/FieldDenseMatrix.java |  8 ++++++--
 .../math4/field/linalg/FieldLUDecomposition.java     |  1 +
 .../geometry/euclidean/threed/FieldRotation.java     | 16 ++++++++--------
 .../euclidean/threed/RotationConvention.java         | 20 +++++++++++---------
 .../geometry/euclidean/threed/RotationOrder.java     |  5 -----
 5 files changed, 26 insertions(+), 24 deletions(-)


[commons-math] 02/02: Javadoc.

Posted by er...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

erans pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-math.git

commit 1c3ccc4d2e560c49b2be2cde352882a4f92dc4e5
Author: Gilles Sadowski <gi...@harfang.homelinux.org>
AuthorDate: Mon Dec 2 08:22:09 2019 +0100

    Javadoc.
---
 .../geometry/euclidean/threed/FieldRotation.java     | 16 ++++++++--------
 .../euclidean/threed/RotationConvention.java         | 20 +++++++++++---------
 .../geometry/euclidean/threed/RotationOrder.java     |  5 -----
 3 files changed, 19 insertions(+), 22 deletions(-)

diff --git a/src/main/java/org/apache/commons/math4/geometry/euclidean/threed/FieldRotation.java b/src/main/java/org/apache/commons/math4/geometry/euclidean/threed/FieldRotation.java
index 2ed4b59..e671acf 100644
--- a/src/main/java/org/apache/commons/math4/geometry/euclidean/threed/FieldRotation.java
+++ b/src/main/java/org/apache/commons/math4/geometry/euclidean/threed/FieldRotation.java
@@ -1155,7 +1155,7 @@ public class FieldRotation<T extends RealFieldElement<T>> implements Serializabl
     }
 
     /** Apply a rotation to a vector.
-     * @param r rotation to apply
+     * @param rot rotation to apply
      * @param u vector to apply the rotation to
      * @param <T> the type of the field elements
      * @return a new vector which is the image of u by the rotation
@@ -1252,7 +1252,7 @@ public class FieldRotation<T extends RealFieldElement<T>> implements Serializabl
     }
 
     /** Apply the inverse of a rotation to a vector.
-     * @param r rotation to apply
+     * @param rot rotation to apply
      * @param u vector to apply the inverse of the rotation to
      * @param <T> the type of the field elements
      * @return a new vector which such that u is its image by the rotation
@@ -1330,7 +1330,7 @@ public class FieldRotation<T extends RealFieldElement<T>> implements Serializabl
     /** Apply the instance to another rotation.
      * <p>
      * Calling this method is equivalent to call
-     * {@link #compose(Rotation, RotationConvention)
+     * {@link #compose(QuaternionRotation, RotationConvention)
      * compose(r, RotationConvention.VECTOR_OPERATOR)}.
      * </p>
      * @param r rotation to apply the rotation to
@@ -1370,7 +1370,7 @@ public class FieldRotation<T extends RealFieldElement<T>> implements Serializabl
     }
 
     /** Compose the instance with another rotation using vector operator convention.
-     * @param r rotation to apply the rotation to
+     * @param rot rotation to apply the rotation to
      * @return a new rotation which is the composition of r by the instance
      * using vector operator convention
      */
@@ -1389,7 +1389,7 @@ public class FieldRotation<T extends RealFieldElement<T>> implements Serializabl
      * vector and v its image by rInner (i.e. rInner.applyTo(u) = v), let w be the image
      * of v by rOuter (i.e. rOuter.applyTo(v) = w), then w = comp.applyTo(u),
      * where comp = applyTo(rOuter, rInner).
-     * @param r1 rotation to apply
+     * @param rot1 rotation to apply
      * @param rInner rotation to apply the rotation to
      * @param <T> the type of the field elements
      * @return a new rotation which is the composition of r by the instance
@@ -1465,7 +1465,7 @@ public class FieldRotation<T extends RealFieldElement<T>> implements Serializabl
     /** Apply the inverse of the instance to another rotation.
      * <p>
      * Calling this method is equivalent to call
-     * {@link #composeInverse(Rotation, RotationConvention)
+     * {@link #composeInverse(QuaternionRotation, RotationConvention)
      * composeInverse(r, RotationConvention.VECTOR_OPERATOR)}.
      * </p>
      * @param r rotation to apply the rotation to
@@ -1509,7 +1509,7 @@ public class FieldRotation<T extends RealFieldElement<T>> implements Serializabl
 
     /** Compose the inverse of the instance with another rotation
      * using vector operator convention.
-     * @param r rotation to apply the rotation to
+     * @param rot rotation to apply the rotation to
      * @return a new rotation which is the composition of r by the inverse
      * of the instance using vector operator convention
      */
@@ -1529,7 +1529,7 @@ public class FieldRotation<T extends RealFieldElement<T>> implements Serializabl
      * let w be the inverse image of v by rOuter
      * (i.e. rOuter.applyInverseTo(v) = w), then w = comp.applyTo(u), where
      * comp = applyInverseTo(rOuter, rInner).
-     * @param rOuter rotation to apply the rotation to
+     * @param rotOuter rotation to apply the rotation to
      * @param rInner rotation to apply the rotation to
      * @param <T> the type of the field elements
      * @return a new rotation which is the composition of r by the inverse
diff --git a/src/main/java/org/apache/commons/math4/geometry/euclidean/threed/RotationOrder.java b/src/main/java/org/apache/commons/math4/geometry/euclidean/threed/RotationOrder.java
index 9fae622..8bd19d5 100644
--- a/src/main/java/org/apache/commons/math4/geometry/euclidean/threed/RotationOrder.java
+++ b/src/main/java/org/apache/commons/math4/geometry/euclidean/threed/RotationOrder.java
@@ -23,11 +23,6 @@ import org.apache.commons.geometry.euclidean.threed.Vector3D;
  * This class is a utility representing a rotation order specification
  * for Cardan or Euler angles specification.
  *
- * This class cannot be instanciated by the user. He can only use one
- * of the twelve predefined supported orders as an argument to either
- * the {@link Rotation#Rotation(RotationOrder,double,double,double)}
- * constructor or the {@link Rotation#getAngles} method.
- *
  * @since 1.2
  */
 public final class RotationOrder {


[commons-math] 01/02: Javadoc.

Posted by er...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

erans pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-math.git

commit a9c64a5002bb05d7209c9dbc5230464e8903e24f
Author: Gilles Sadowski <gi...@harfang.homelinux.org>
AuthorDate: Mon Dec 2 08:21:50 2019 +0100

    Javadoc.
---
 .../org/apache/commons/math4/field/linalg/FieldDenseMatrix.java   | 8 ++++++--
 .../apache/commons/math4/field/linalg/FieldLUDecomposition.java   | 1 +
 2 files changed, 7 insertions(+), 2 deletions(-)

diff --git a/src/main/java/org/apache/commons/math4/field/linalg/FieldDenseMatrix.java b/src/main/java/org/apache/commons/math4/field/linalg/FieldDenseMatrix.java
index 8fd0dc1..d901819 100644
--- a/src/main/java/org/apache/commons/math4/field/linalg/FieldDenseMatrix.java
+++ b/src/main/java/org/apache/commons/math4/field/linalg/FieldDenseMatrix.java
@@ -63,9 +63,11 @@ public class FieldDenseMatrix<T>
     /**
      * Factory method.
      *
+     * @param <T> Type of the field elements.
      * @param f Field.
      * @param r Number of rows.
      * @param c Number of columns.
+     * @return a new instance.
      * @throws IllegalArgumentException if {@code r <= 0} or {@code c <= 0}.
      */
     public static <T> FieldDenseMatrix<T> create(Field<T> f,
@@ -77,11 +79,12 @@ public class FieldDenseMatrix<T>
     /**
      * Factory method.
      *
+     * @param <T> Type of the field elements.
      * @param f Field.
      * @param r Number of rows.
      * @param c Number of columns.
-     * @throws IllegalArgumentException if {@code r <= 0} or {@code c <= 0}.
      * @return a matrix with elements zet to {@link Field#zero() zero}.
+     * @throws IllegalArgumentException if {@code r <= 0} or {@code c <= 0}.
      */
     public static <T> FieldDenseMatrix<T> zero(Field<T> f,
                                                int r,
@@ -92,10 +95,11 @@ public class FieldDenseMatrix<T>
     /**
      * Factory method.
      *
+     * @param <T> Type of the field elements.
      * @param f Field.
      * @param n Dimension of the matrix.
-     * @return the identity matrix.
      * @throws IllegalArgumentException if {@code n <= 0}.
+     * @return the identity matrix.
      */
     public static <T> FieldDenseMatrix<T> identity(Field<T> f,
                                                    int n) {
diff --git a/src/main/java/org/apache/commons/math4/field/linalg/FieldLUDecomposition.java b/src/main/java/org/apache/commons/math4/field/linalg/FieldLUDecomposition.java
index ab53e29..137bcbd 100644
--- a/src/main/java/org/apache/commons/math4/field/linalg/FieldLUDecomposition.java
+++ b/src/main/java/org/apache/commons/math4/field/linalg/FieldLUDecomposition.java
@@ -142,6 +142,7 @@ public class FieldLUDecomposition<T> {
     /**
      * Factory method.
      *
+     * @param <T> Type of the field elements.
      * @param m Matrix to decompose.
      * @return a new instance.
      */
diff --git a/src/main/java/org/apache/commons/math4/geometry/euclidean/threed/RotationConvention.java b/src/main/java/org/apache/commons/math4/geometry/euclidean/threed/RotationConvention.java
index 0c4eb80..a80fe9b 100644
--- a/src/main/java/org/apache/commons/math4/geometry/euclidean/threed/RotationConvention.java
+++ b/src/main/java/org/apache/commons/math4/geometry/euclidean/threed/RotationConvention.java
@@ -17,9 +17,11 @@
 
 package org.apache.commons.math4.geometry.euclidean.threed;
 
+import org.apache.commons.geometry.euclidean.threed.Vector3D;
+
 /**
  * This enumerates is used to differentiate the semantics of a rotation.
- * @see Rotation
+ * @see FieldRotation
  * @since 3.6
  */
 public enum RotationConvention {
@@ -31,10 +33,10 @@ public enum RotationConvention {
      * </p>
      * <p>
      * This means that if we define rotation r is a 90 degrees rotation around
      * the Z axis, the image of vector {@link Cartesian3D#PLUS_I} would be
      * {@link Cartesian3D#PLUS_J}, the image of vector {@link Cartesian3D#PLUS_J}
      * would be {@link Cartesian3D#MINUS_I}, the image of vector {@link Cartesian3D#PLUS_K}
      * would be {@link Cartesian3D#PLUS_K}, and the image of vector with coordinates (1, 2, 3)
      * would be vector (-2, 1, 3). This means that the vector rotates counterclockwise.
      * </p>
      * <p>
@@ -58,10 +60,10 @@ public enum RotationConvention {
      * </p>
      * <p>
      * This means that if we define rotation r is a 90 degrees rotation around
      * the Z axis, the image of vector {@link Cartesian3D#PLUS_I} would be
      * {@link Cartesian3D#MINUS_J}, the image of vector {@link Cartesian3D#PLUS_J}
      * would be {@link Cartesian3D#PLUS_I}, the image of vector {@link Cartesian3D#PLUS_K}
      * would be {@link Cartesian3D#PLUS_K}, and the image of vector with coordinates (1, 2, 3)
      * would be vector (2, -1, 3). This means that the coordinates of the vector rotates
      * clockwise, because they are expressed with respect to a destination frame that is rotated
      * counterclockwise.
@@ -31,10 +33,10 @@ public enum RotationConvention {
      * <p>
      * This means that if we define rotation r is a 90 degrees rotation around
-     * the Z axis, the image of vector {@link Cartesian3D#PLUS_I} would be
-     * {@link Cartesian3D#PLUS_J}, the image of vector {@link Cartesian3D#PLUS_J}
-     * would be {@link Cartesian3D#MINUS_I}, the image of vector {@link Cartesian3D#PLUS_K}
-     * would be {@link Cartesian3D#PLUS_K}, and the image of vector with coordinates (1, 2, 3)
+     * the Z axis, the image of vector {@link Vector3D.Unit#PLUS_X} would be
+     * {@link Vector3D.Unit#PLUS_Y}, the image of vector {@link Vector3D.Unit#PLUS_Y}
+     * would be {@link Vector3D.Unit#MINUS_X}, the image of vector {@link Vector3D.Unit#PLUS_Z}
+     * would be {@link Vector3D.Unit#PLUS_Z}, and the image of vector with coordinates (1, 2, 3)
      * would be vector (-2, 1, 3). This means that the vector rotates counterclockwise.
      * </p>
@@ -58,10 +60,10 @@ public enum RotationConvention {
      * <p>
      * This means that if we define rotation r is a 90 degrees rotation around
-     * the Z axis, the image of vector {@link Cartesian3D#PLUS_I} would be
-     * {@link Cartesian3D#MINUS_J}, the image of vector {@link Cartesian3D#PLUS_J}
-     * would be {@link Cartesian3D#PLUS_I}, the image of vector {@link Cartesian3D#PLUS_K}
-     * would be {@link Cartesian3D#PLUS_K}, and the image of vector with coordinates (1, 2, 3)
+     * the Z axis, the image of vector {@link Vector3D.Unit#PLUS_X} would be
+     * {@link Vector3D.Unit#MINUS_Y}, the image of vector {@link Vector3D.Unit#PLUS_Y}
+     * would be {@link Vector3D.Unit#PLUS_X}, the image of vector {@link Vector3D.Unit#PLUS_Z}
+     * would be {@link Vector3D.Unit#PLUS_Z}, and the image of vector with coordinates (1, 2, 3)
      * would be vector (2, -1, 3). This means that the coordinates of the vector rotates
      * clockwise, because they are expressed with respect to a destination frame that is rotated